
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				09/14/2021
Last update: 		05/02/2024
================================================================================================

MASTER.DO

Descrption: Runs all the do-files in the project

==============================================================================================*/
set varabbrev on
etime, start
drop _all
version 14
set matsize 5000

/*==============================================================================================
 	0 - Setting
==============================================================================================*/

* Globals for directories 
gl path			"C:\Users\wb614536\Documents\RR_LAC_2024_144\files submitted\RR_GJ_2024"	// Change for working directory
gl do_files		"${path}\Do_files"		// .do files directory
gl data 		"${path}\Data" 			// Directory for data files
gl output		"${path}\Outputs"		// Directory for output files
gl sedlac 		"${data}\sedlac"		// Directory for sedlac modified data

* change ado folder 

sysdir set PLUS "$do_files/ado"

* Input databases
gl base_in_1  "${data}\cait\CW_CAIT_GHG_Emissions.xlsx"
gl base_in_2  "${data}\cait\world_ghge_2015.dta"
gl base_in_3  "${data}\cait\world_ghge_05_18.dta"
gl base_in_4  "${data}\oecd\ghg_emissions.xlsx"
gl base_in_5  "${data}\oecd\ghg_emissions_organized.dta"
gl base_in_6  "${data}\sedlac\workers_by_sector_15to64.dta"
gl base_in_7  "${data}\sedlac\employees_15more.dta"
gl base_in_8  "${data}\o-net\Green Occupations.xlsx"
gl base_in_9  "${data}\o-net\Related Occupations Matrix.xlsx"
gl base_in_10 "${data}\o-net\2010_Occupations.xlsx"
gl base_in_11 "${data}\bls\national_M2018_dl.xlsx"
gl base_in_12 "${data}\bls\isco_soc_crosswalk_stata.xlsx"
gl base_in_13 "${data}\ilo\employment_sex_2d.dta"
gl base_in_14 "${data}\wdi\gdp_pc.xlsx"
gl base_in_15 "${data}\ilo\EMP_NIFL_SEX_RT_A-full-2021-12-27.dta"
gl base_in_16 "${data}\hci\HCIEXCEL.xlsx"
gl base_in_17 "${data}\oecd\green_growth_indicators.xlsx"
gl base_in_18 "${data}\oecd\environmental_policy_stringency.xlsx"
gl base_in_19 "${data}\oecd\environmentally_related_tax_revenue.xlsx"
gl base_in_20 "${data}\oecd\trade_in_environmentally_related_goods.csv"
gl base_in_21 "${data}\wdi\environmental_variables.xlsx"
gl base_in_22 "${data}\wdi\CLASS.xlsx"
gl base_in_23 "${data}\wdi\gdp.xlsx"
gl base_in_24 "${data}\wdi\controls.xlsx"

* Output databases
gl base_out_1  "${data}\own production\estimated_emissions.dta"
gl base_out_2  "${data}\own production\Emissions.dta"
gl base_out_3  "${data}\own production\LAC_estimated_emissions.dta"
gl base_out_4  "${data}\own production\Emissions_per_worker.dta"
gl base_out_5  "${data}\own production\green_occ_isco08_4d.dta"
gl base_out_6  "${data}\own production\green_occ_isco08_1d.dta"
gl base_out_7  "${data}\own production\green_occ_isco08_2d.dta"
gl base_out_8  "${data}\own production\green_occ_isco08_3d.dta"
gl base_out_9  "${data}\own production\ilo_proccessed.dta"
gl base_out_10 "${data}\own production\ilo_proccessed_with_lac.dta"
gl base_out_11 "${data}\own production\ilo_proccessed_with_lac_wdi.dta"
gl base_out_12 "${data}\own production\green_levels.dta"

* Output Tables 
gl table_6    "${output}\Table_6.xlsx"  	// Comparison of estimated GHG emissions (2015 data)
gl table_7	  "${output}\Table_7.xlsx"  	// Green (green color) and non-green (brown color) sectors
gl table_8	  "${output}\Table_8.xls"   	// Green jobs and labor income in LAC, circa 2019
gl table_9a	  "${output}\Table_9a.xlsx"   	// % workers in new and emerging - by country and ISCO 1d.
gl table_9b	  "${output}\Table_9b.xlsx"   	// % workers in enhanced skills - by country and ISCO 2d.
gl table_9c	  "${output}\Table_9c.xlsx"   	// % workers in increased demand - by country and ISCO 3d.
gl table_9d	  "${output}\Table_9d.xlsx"  	// % workers in green occupations - by country and ISCO 4d.
gl table_a1   "${output}\Table_A1.xlsx" 	// Share of green occupations, latest available data
gl table_a4_a "${output}\Table_A4_a.xls" 	// Fixed eff reg of GJ and GHGE on economic dev., unbalanced 2001-2020.
gl table_a4_b "${output}\Table_A4_b.xls" 	// Fixed eff reg of GJ and GHGE on economic dev., balanced 2011-2019.
gl table_a7_a "${output}\Table_A7_a.xlsx" 	// Occupations with highest shares - Females
gl table_a7_b "${output}\Table_A7_b.xlsx" 	// Occupations with highest shares - Males
gl table_a8   "${output}\Table_A8.xlsx" 	// Share of green and non-green occupations in the agriculture by ISCO

* Output Figures 
gl figure_2	   "${output}\Figure_2.xlsx"    // Green occupations (all types) across the world.
gl figure_3    "${output}\Figure_3.xlsx"    // Green occupations (by types) across the world.
gl figure_4    "${output}\Figure_4.xlsx"    // % of green occupations and GDP per capita (2017 PPP $).
gl figure_5    "${output}\Figure_5.xlsx"    // Green occupations and green sectors in LAC
gl figure_6    "${output}\Figure_6.xlsx"    // % of non-green occupations in the agriculture sector, LAC countries
gl figure_7    "${output}\Figure_7.xlsx"    // Jobs in green and non-green occupations and sectors in LAC 2010-2019
gl figure_8    "${output}\Figure_8.xlsx"    // Decomposition of the change in GHG emissions (tn.) per worker
gl figure_9    "${output}\Figure_9.xlsx"    // Green and non-green gender, education, and rural/urban
gl figure_10   "${output}\Figure_10.xlsx"   // Gender Gaps in green occupations
gl figure_11   "${output}\Figure_11.xlsx"   // Green occupations by education level, LAC 2019
gl figure_12   "${output}\Figure_12.xlsx"   // Green and non-green informality and firm size
gl figure_13   "${output}\Figure_13.xlsx"   // Green and non-green occupations by household income quintile
gl figure_14   "${output}\Figure_14.xlsx"   // Green and non-green household income quintiles
gl figure_15   "${output}\Figure_15.xlsx"   // Green occupations as % of the W.A.P. and as % of total employment.
gl figure_a2   "${output}\Figure_A2.xlsx"   // Green occupations (all types) across the world, regional level.
gl figure_a3   "${output}\Figure_A3.xlsx"  	// Green occ. and green sectors in LAC (all serv gr, non-serv poll)
gl figure_a5   "${output}\Figure_A5.xlsx"  	// Green and non-green HH income quintiles (all serv gr, non-serv poll)
gl figure_a6_a "${output}\Figure_A6_a.xlsx" // Green occupations, human capital and informality
gl figure_a6_b "${output}\Figure_A6_b.xlsx" // Green occupations and labor market informality


/*==============================================================================================
 	1 - Run the program
==============================================================================================*/

* 1.1 -  Creates GHGE dataset from CAIT
	run "$do_files\01_GHGE_data.do"

* 1.2 -  Generates GHGE estimates for world countries and year 2015
	run "$do_files\02_GHGE_estimation_world.do"

* 1.3 -  Creates GHGE dataset from CAIT
	run "$do_files\03_GHGE_oecd_lac.do"

* 1.4 -  Compares GHG emissions from estimation with WDI, OECD, and CAIT
	run "$do_files\04_estimates_comparison_LAC.do"

* 1.5 -  Generates GHGE estimates for LAC countries and years 2005 - 2018
	run "$do_files\05_GHGE_estimation_LAC.do"

* 1.6 -  Emissions per worker
	run "$do_files\06_emissions_per_worker.do"

* 1.7 -  Generate databases with green occupations at the different digit levels of the ISCO-08
	run "$do_files\07_green_occ.do"

* 1.8 -  Process employment database from ILOSTAT
	run "$do_files\08_process_ilostat.do"

* 1.9 -  Merge the green share database from ILOSTAT with the green share of SEDLAC
	run "$do_files\09_merges_ilo_sedlac.do"

* 1.10 - Cross country statistics based on last available data in ILO/SEDLAC database & WDI data
	run "$do_files\10_cross_country_stats.do"

* 1.11 - Creating LAC appends database using SEDLAC for each circa
	run "$do_files\11_lac_appends.do"

* 1.12 - Green jobs Circa 2019
	run "$do_files\12_green_jobs_circa_2019.do"

* 1.13 - Non-green jobs in Agriculture
	run "$do_files\13_non_green_jobs_agriculture.do"

* 1.14 - Green jobs full series 
	run "$do_files\14_green_jobs_lac_series.do"

* 1.15 - Regressions: Green jobs only and green jobs / green sectors cross-classification
	run "$do_files\15_regressions.do"

* 1.16 - Process OECD and WDI databases and merges to green employment database from ILO/SEDLAC
	run "$do_files\16_process_environmental_variables.do"

* 1.17 - Environmental regressions
	run "$do_files\17_environmental_regressions.do"

* 1.18 - Generate descriptive statistics based on SEDLAC
	run "$do_files\18_descriptive_sedlac.do"

* 1.19 - Decomposition of the change in emissions over time
	run "$do_files\19_decompo_emissions.do"

* 1.20 - Green jobs Circa 2019 with reclassification of sectors ( All services Green, Non-services Pollutant)
	run "$do_files\20_green_jobs_circa_2019_Annex.do"

* Display running time	
etime

/*==============================================================================================
  - END
==============================================================================================*/