
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				11/08/2021
Last update: 		05/02/2024
================================================================================================

GHGE_OECD_LAC.DO

Description: This dofile selects sectors and years from OECD Stats GHG emissions database to be compared with the new estimates.

* Source: OECD data explorer.
* Data version Apr 17th, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - GHG Emissions data, 2014-2015, LAC countries
==============================================================================================*/

* Import data
import excel "${base_in_4}", sheet("OECD.Stat export") clear

* Cleaning the database
drop in 1/5
keep A B D E
drop if inlist(E,"",".","..")
drop in 59/60

* Filling out country's name variable
replace B = A if B == ""
drop A

* Rename variables
ren (B D E) (countryname y_2014 y_2015)

* Drop firstrow and destring
drop in 1
destring * , replace

* Changing display format 
format countryname %30s
keep if inlist(countryname,"Chile","  Argentina","  Brazil","  Peru","Colombia","Costa Rica","Mexico")

* Country codes
gen country = ""
replace country = "CHL" if countryname == "Chile"
replace country = "COL" if countryname == "Colombia"
replace country = "CRI" if countryname == "Costa Rica"
replace country = "MEX" if countryname == "Mexico"
replace country = "ARG" if countryname == "  Argentina"
replace country = "BRA" if countryname == "  Brazil"
replace country = "PER" if countryname == "  Peru"

* Dropping spaces in some country names 
replace countryname = "Argentina" 	if countryname == "  Argentina"
replace countryname = "Brazil" 		if countryname == "  Brazil"
replace countryname = "Peru" 		if countryname == "  Peru"

* Ordering, sorting, and saving the data
order country
sort countryname

save "${base_in_5}", replace

/*==============================================================================================
  - END
==============================================================================================*/