
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				10/07/2021
Last update: 		05/02/2024
================================================================================================

ESTIMATES_COMPARISON_LAC.DO

Description: This dofiles compares the estimates with OCDE, CAIT, and WDI GHG emissions data.

* Source: OECD Data Explorer and WDI (WB).
* Data version Apr 17, 2024 for OECD and Nov 18th, 2022 for WDI.

==============================================================================================*/


/*==============================================================================================
	1 - Merge GHGE from the different sources
==============================================================================================*/

* WDI - Total greenhouse gas emissions (kt of CO2 equivalent) "EN.ATM.GHGT.KT.CE"
qui wbopendata, year(2014:2016) indicator(EN.ATM.GHGT.KT.CE) clear
keep if region == "LCN"
ren countrycode country
keep country yr2015
replace yr2015 = yr2015 / 1000 // Change to Mt
ren yr2015 wdi

* Estimated emissions
merge 1:1 country using "${base_out_2}", keep(3) nogenerate
drop *sector*
ren total estimation

* CAIT
merge 1:m country using "${base_in_2}", keep(3) keepusing(ghg_excLUCF) nogenerate
duplicates drop
ren ghg_excLUCF cait

* OECD
merge 1:m country using "${base_in_5}", keep(3) keepusing (y_2015) nogenerate
duplicates drop
replace y_2015 = y_2015 / 1000 // Change to Mt
ren y_2015 oecd

* Table 6 – Comparison of estimated GHG emissions (Megatons) with other sources (2015 data)
order country estimation wdi cait oecd
la var country 		"Country"
la var estimation 	"Own Estimation"
la var wdi 			"WDI"
la var cait 		"CAIT"
la var oecd 		"OECD"
export excel using "${table_6}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/